#!/bin/bash

#Company:       PowerCraft Technology
#Author:        Copyright Jelle de Jong <jelledejong@powercraft.nl>
#Note:          Please send me an email if you enhanced this script
#Version:       0.0.3
#Date:          04-07-2007 / 30-12-2007 / 2008-11-19
#System:        Debian sid
#Category       Thunar scripts (thunar->edit->custom actions)
#Name:          Open File(s)
#Description:   Open all legal files in the directory
#Command:       xfce4-terminal --disable-server --hide-toolbars --execute /usr/share/pct-thunar-scripts/scripts/directory-open-file.sh %F
#Patterns:      *
#Directories:   True

# Did the script work for you?
# Yes
# Yes, but with some errors
# Yes, but I had to change some things
# Not at all

# Note: i think its better to use xdg-open but it has some controll issues

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301, USA.

cecho()
{
    if [ "$1" = "black" ]; then
        echo -ne "\E[30m"
    elif [ "$1" = "red" ]; then
        echo -ne "\E[31m"
    elif [ "$1" = "green" ]; then
        echo -ne "\E[32m"
    elif [ "$1" = "yellow" ]; then
        echo -ne "\E[33m"
    elif [ "$1" = "blue" ]; then
        echo -ne "\E[34m"
    elif [ "$1" = "magenta" ]; then
        echo -ne "\E[35m"
    elif [ "$1" = "cyan" ]; then
        echo -ne "\E[36m"
    fi

    echo "$2" "$3"
    tput sgr0
}

cecho "green" "processing directory:"
for I in "$@"
do
    directory=${I##*/}
    cecho "blue" "$directory"
done

cecho "blue" "---------------"

open_mp3_file()
{
    check_program mpg123
    echo "opening the following files with mpg123:"
    cecho "green" "$@"
    aoss mpg123 -C -v "$@" &
}

open_ogg_file()
{
    check_program ogg123
    echo "opening the following files with aoss ogg123:"
    cecho "green" "$@"
    aoss ogg123 "$@" &
}

open_flac_file()
{
    check_program flac123
    echo "opening the following files with aoss flac123:"
    cecho "green" "$@"
    aoss flac123 "$@" &
}

open_evince_file()
{
    check_program evince
    echo "opening the following files with evince:"
    cecho "green" "$@"
    evince "$@" &
}

open_totem_file()
{
    check_program totem
    echo "opening the following files with totem:"
    cecho "green" "$@"
    totem "$@" &
}

open_geany_file()
{
    check_program geany
    echo "opening the following files with geany:"
    cecho "green" "$@"
    geany "$@" &
}


check_program()
{
    #whereis pdftk
    if [ ! -e /usr/bin/$1 ]
    then
        cecho "red" "$1 not found, installing now"
        sudo apt-get install "$1"
    fi
}

unset mp3_query
unset ogg_query
unset flac_query
unset evince_query
unset totem_query
unset geany_query

scan_directory()
{
    for file in "$1"/*
    do
        if [ -f "$file" ]
        then
            extension=${file##*.}
            extension=$(echo "$extension" | tr '[:upper:]' '[:lower:]')
            [[ "$extension" = mp3 ]] && mp3_query+=("$file")
            [[ "$extension" = ogg ]] && ogg_query+=("$file")
            [[ "$extension" = flac ]] && flac_query+=("$file")
            [[ "$extension" = pdf ]] && evince_query+=("$file")
            [[ "$extension" = avi ]] && totem_query+=("$file")
            [[ "$extension" = mpg ]] && totem_query+=("$file")
            [[ "$extension" = vob ]] && totem_query+=("$file")
            [[ "$extension" = txt ]] && geany_query+=("$file")
        fi

        if [ -d "$file" ]
        then
            scan_directory "$file"
        fi
    done
}

for I in "$@"
do
    cecho "green" "starting:"

    if [ -d "$I" ]
    then
        scan_directory "$I"
    fi

    cecho "green" "completed:"
    cecho "blue" "---------------"
done

if [ -n "$mp3_query" ]
then
    open_mp3_file "${mp3_query[@]}"
fi

if [ -n "$ogg_query" ]
then
    open_ogg_file "${ogg_query[@]}"
fi

if [ -n "$flac_query" ]
then
    open_flac_file "${flac_query[@]}"
fi

if [ -n "$evince_query" ]
then
    open_evince_file "${evince_query[@]}"
fi

if [ -n "$totem_query" ]
then
    open_totem_file "${totem_query[@]}"
fi

if [ -n "$geany_query" ]
then
    open_geany_file "${geany_query[@]}"
fi

cecho "blue" -n "done, are you sure you want to exit all openend files [Y/n]? "
read input
if [ "$input" = "n" ]
then
    exit 0
fi

cecho "green" "done, closing after 3 seconds"

sleep 3

exit
