#!/bin/bash

#Company:       PowerCraft Technology
#Author:        Copyright Jelle de Jong <jelledejong@powercraft.nl>
#Note:          Please send me an email if you enhanced this script
#Version:       0.0.3
#Date:          21-11-06 / 10-11-07 / 12-02-08
#System:        Xubuntu 7.10
#Information:   man ffplay
#Category       Thunar scripts
#Name:          Play Video
#Description:   Play a video file
#Command:       xfce4-terminal --disable-server --hide-toolbars --execute /usr/share/pct-thunar-scripts/scripts/play-video.sh %F
#Patterns:      *
#Directories:   True
#Video Files:   True

# Did the script work for you?
# Yes
# Yes, but with some errors
# Yes, but I had to change some things
# Not at all

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301, USA.

#nice -n -1 ffplay "$1"
#xfce4-terminal -x sudo nice -n -1 ffplay -vn -nodisp "$1"
#ffplay -vn "$1"

cecho()
{
    if [ "$1" = "black" ]; then
        echo -ne "\E[30m"
    elif [ "$1" = "red" ]; then
        echo -ne "\E[31m"
    elif [ "$1" = "green" ]; then
        echo -ne "\E[32m"
    elif [ "$1" = "yellow" ]; then
        echo -ne "\E[33m"
    elif [ "$1" = "blue" ]; then
        echo -ne "\E[34m"
    elif [ "$1" = "magenta" ]; then
        echo -ne "\E[35m"
    elif [ "$1" = "cyan" ]; then
        echo -ne "\E[36m"
    fi

    echo "$2" "$3"
    tput sgr0
}

play_video_file()
{
    check_program ffplay
    check_program totem

    cecho "green" "choose a programm and press enter"
    cecho "red" "[1] ffplay"
    cecho "red" "[2] gxine"
    cecho "red" "[3] totem-xine"
    cecho "red" "[4] totem-gstreamer"
    cecho "red" "[5] exit"
    read option
    if [ "$option" = "1" ]
    then
        echo "starting fflpay command, please standby"
        ffplay "$@"
    fi

    if [ "$option" = "2" ]
    then
        echo "starting gxine command, please standby"
        gxine "$@"
    fi

    if [ "$option" = "3" ]
    then
        echo "starting totem-xine command, please standby"
        totem-xine "$@"
    fi

    if [ "$option" = "4" ]
    then
        echo "starting totem-gstreamer command, please standby"
        totem-gstreamer "$@"
    fi

    if [ "$option" = "5" ]
    then
        exit
    fi
}

check_program()
{
    #whereis ffplay
    application="$1"

    if [ ! -e /usr/bin/$application ]
    then
        echo "red" "$application not found, installing now"
        if [ "$application" = "ogg123" ]
        then
            application="vorbis-tools"
        fi
        if [ "$application" = "ffplay" ]
        then
            application="ffmpeg"
        fi
        sudo apt-get install "$application"
    fi
}

scan_directory()
{
    #step 1: is there a mp3 in the folder
    #step 2: query that mp3
    #step 3: check for other folders
    #step 4: scan that folder and repeat

    #find / -type f -name '*.mp3' -exec mpg123 -C -v {} \;
    #query+=$(find "$1" -name *.mp3)
    #var1="test one.mp3";var2="test two.mp3";unset query;set -x;query+=("$var1");query+=("$var2");mpg123 -C -v -a /dev/dsp "${query[@]}"

    for file in "$1"/*
    do
        if [ -f "$file" ]
        then
            echo "checking file:" ${file##*/}
            extension=${file##*.}
            extension=$(echo $extension | tr '[:upper:]' '[:lower:]')
            [[ "$extension" = mpg ]] && video_query+=("$file") && echo "filling: mpg video query:" ${file##*/}
            [[ "$extension" = avi ]] && video_query+=("$file") && echo "filling: avi video query:" ${file##*/}
            [[ "$extension" = wmv ]] && video_query+=("$file") && echo "filling: avi video query:" ${file##*/}
        fi

        if [ -d "$file" ]
        then
            echo "checking directory:" ${file##*/}
            scan_directory "$file"
        fi
    done
}

cecho "green" "processing:"
for I in "$@"
do
    filename=${I##*/}
    cecho "blue" "$filename"
done

cecho "blue" "---------------"

unset video_query

for I in "$@"
do
    cecho "green" "starting: "

    if [ -f "$I" ]
    then
        echo "checking file:" ${I##*/}
        extension=${I##*.}
        extension=$(echo $extension | tr '[:upper:]' '[:lower:]')
        [[ "$extension" = mpg ]] && video_query+=("$I") && echo "filling: mpg video query:" ${I##*/}
        [[ "$extension" = avi ]] && video_query+=("$I") && echo "filling: avi video query:" ${I##*/}
        [[ "$extension" = wmv ]] && video_query+=("$I") && echo "filling: avi video query:" ${file##*/}
        [[ "$extension" = mkv ]] && video_query+=("$I") && echo "filling: mkv video query:" ${file##*/}
    fi

    if [ -d "$I" ]
    then
        echo "checking directory:" ${I##*/}
        scan_directory "$I"
    fi

    cecho "green" "completed:"
    cecho "blue" "---------------"
done

if [ -n "$video_query" ]
then
    play_video_file "${video_query[@]}"
fi

cecho "green" "done, closing after 5 seconds"
rm $HOME/.recently-used.xbel
sleep 5

exit
